'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  initializing: function () {
    this.pkg = require('../package.json');
  },

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the stylish ' + chalk.red('AngularNeat') + ' generator!'
    ));

    var prompts = [{
      type: 'confirm',
      name: 'someOption',
      message: 'Would you like to enable this option?',
      default: true
    }];

    this.prompt(prompts, function (props) {
      this.someOption = props.someOption;

      done();
    }.bind(this));
  },

  createFolders: function() {
    this.mkdir('app');
    this.mkdir('app/styles');
    this.mkdir('app/scripts');
    this.mkdir('app/scripts/controllers');
    this.mkdir('app/images');
    this.mkdir('app/views');
    this.mkdir('build');
    this.mkdir('test');
    this.mkdir('test/spec');
    this.mkdir('test/spec/controllers');
  },

  writing: {
    app: function () {

      // Copy Build-Related Files
      this.fs.copy(
        this.templatePath('build/*'),
        this.destinationPath('build/')
      );

      // Copy Project Assets
      this.fs.copy(
        this.templatePath('_package.json'),
        this.destinationPath('package.json')
      );
      this.fs.copy(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json')
      );
      this.fs.copy(
        this.templatePath('_travis.yml'),
        this.destinationPath('travis.yml')
      );
      this.fs.copy(
        this.templatePath('_Gruntfile.js'),
        this.destinationPath('Gruntfile.js')
      );
      this.fs.copy(
        this.templatePath('bowerrc'),
        this.destinationPath('.bowerrc')
      );
      this.fs.copy(
        this.templatePath('_karma.conf.js'),
        this.destinationPath('test/karma.conf.js')
      );
      this.fs.copy(
        this.templatePath('_home-spec.js'),
        this.destinationPath('test/spec/controllers/home-spec.js')
      );

      // Copy App Assets: Root
      this.fs.copy(
        this.templatePath('_app.js'),
        this.destinationPath('app/scripts/app.js')
      );
      this.fs.copy(
        this.templatePath('_index.html'),
        this.destinationPath('app/index.html')
      );
      this.fs.copy(
        this.templatePath('robots.txt'),
        this.destinationPath('app/robots.txt')
      );

      // Copy App Assets: Controllers
      this.fs.copy(
        this.templatePath('controllers/*'),
        this.destinationPath('app/scripts/controllers/*')
      );

      // Copy App Assets: Styles
      this.fs.copy(
        this.templatePath('_main.less'),
        this.destinationPath('app/styles/main.less')
      );
      this.fs.copy(
        this.templatePath('csslintrc'),
        this.destinationPath('.csslintrc')
      );

      // Copy App Assets: Views
      this.fs.copy(
        this.templatePath('views/*'),
        this.destinationPath('app/views/')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('jshintrc'),
        this.destinationPath('.jshintrc')
      );
    }
  },

  install: function () {
    this.installDependencies({
      skipInstall: this.options['skip-install']
    });
  }
});
